/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.update;

import org.eobjects.metamodel.DataContext;
import org.eobjects.metamodel.MetaModelException;
import org.eobjects.metamodel.data.RowBuilder;
import org.eobjects.metamodel.query.FilterItem;
import org.eobjects.metamodel.query.builder.FilterBuilder;
import org.eobjects.metamodel.schema.Column;
import org.eobjects.metamodel.schema.Table;

/**
 * Builder object for row update on a {@link Table}.
 * 
 * @author Kasper Sørensen
 */
public interface RowUpdationBuilder extends RowBuilder<RowUpdationBuilder> {
    
    /**
     * Defines a where item to set as a criteria for this update
     * 
     * @param column
     *            a column to apply a criteria for
     * @return a {@link FilterBuilder} for further building the where item
     */
    public FilterBuilder<RowUpdationBuilder> where(Column column);

    /**
     * Defines a where item to set as a criteria for this update
     * 
     * @param columnName
     *            the name of the colum to which the criteria will be applied
     * @return a {@link FilterBuilder} for further building the where item
     */
    public FilterBuilder<RowUpdationBuilder> where(String columnName);

    /**
     * Applies where items to set criteria for this update
     * 
     * @param filterItems
     *            the where items to set
     * @return the {@link RowUpdationBuilder} itself, for further building of
     *         the update
     */
    public RowUpdationBuilder where(FilterItem... filterItems);

    /**
     * Applies where items to set criteria for this update
     * 
     * @param filterItems
     *            the where items to set
     * @return the {@link RowUpdationBuilder} itself, for further building of
     *         the update
     */
    public RowUpdationBuilder where(Iterable<FilterItem> filterItems);

    /**
     * Gets a SQL representation of this update operation. Note that the
     * generated SQL is dialect agnostic, so it is not accurately the same as
     * what will be passed to a potential backing database.
     * 
     * @return a SQL representation of this update operation.
     */
    public String toSql();

    /**
     * Commits the row updation operation. This operation will overwrite rows in
     * the {@link DataContext}.
     * 
     * @throws MetaModelException
     *             if the operation was rejected
     */
    public void execute() throws MetaModelException;
}
